@@ -1555,7 +1555,7 @@ int define_surveys(char surveynames[MAX_STRLEN][MAX_SURVEYS])
   strcpy(surveynames[20],"FermiBlind");
   strcpy(surveynames[21],"htru_pks");
   strcpy(surveynames[22],"FermiAssoc");
-  strcpy(surveynames[23],"gb350");
+  strcpy(surveynames[23],"gbt350");
   strcpy(surveynames[24],"pkspa");
   strcpy(surveynames[25],"pksngp");
   strcpy(surveynames[26],"htru_eff");
@@ -1565,9 +1565,12 @@ int define_surveys(char surveynames[MAX_STRLEN][MAX_SURVEYS])
   strcpy(surveynames[30],"pks_superb");
   strcpy(surveynames[31],"lotaas");
   strcpy(surveynames[32],"fast_uwb");
-  strcpy(surveynames[32],"fast_gpps");
-  
-  survey_num=33;
+  strcpy(surveynames[33],"fast_gpps");
+  strcpy(surveynames[34],"chime");
+  strcpy(surveynames[35],"meerkat_trapum");
+  strcpy(surveynames[36],"fast_mb");
+  strcpy(surveynames[37],"tulipp");
+  survey_num=37;
   return survey_num;
 }
 
